@@ -27,18 +27,17 @@
 #ifndef AMORDIALOG_H
 #define AMORDIALOG_H
 
-#include <qdialog.h>
-#include <qlistbox.h>
-#include <qptrlist.h>
-#include <qmultilineedit.h>
+#include <kdialog.h>
 #include "amorconfig.h"
-#include <kdialogbase.h>
+
+class QListWidget;
+class KTextEdit;
 
 //---------------------------------------------------------------------------
 //
 // AmorDialog provides a setup dialog.
 //
-class AmorDialog : public KDialogBase
+class AmorDialog : public KDialog
 {
     Q_OBJECT
 
@@ -75,33 +74,11 @@ protected:
     void addTheme(const QString& file);
 
 protected:
-    QListBox *mThemeListBox;
-    QMultiLineEdit *mAboutEdit;
+    QListWidget *mThemeListView;
+    KTextEdit *mAboutEdit;
     QStringList mThemes;
     QStringList mThemeAbout;
     AmorConfig mConfig;
 };
 
-//---------------------------------------------------------------------------
-//
-// AmorListBoxItem implements a list box items for selection of themes
-//
-class AmorListBoxItem : public QListBoxItem
-{
-public:
-    AmorListBoxItem(const QString & s, const QPixmap& p)
-        : QListBoxItem(), mPixmap(p)
-        { setText(s); }
-
-protected:
-    virtual void paint(QPainter *);
-    virtual int height(const QListBox *) const;
-    virtual int width(const QListBox *) const;
-    virtual const QPixmap *pixmap() const { return &mPixmap; }
-
-private:
-    QPixmap mPixmap;
-};
-
 #endif // AMORDIALOG_H
-
