@@ -18,28 +18,28 @@
 #ifndef REPORTVIEW_H
 #define REPORTVIEW_H
 
-#include <kdialogbase.h>
-#include <qstringlist.h>
+#include <kdialog.h>
 
+#include <QtCore/QStringList>
 
+class OrgKdeKweatherServiceInterface;
 class KHTMLPart;
-class WeatherService_stub;
 
 /**This is the main report generated for the user.
   *@author Ian Reinhart Geiser
   */
 
-class reportView : public KDialogBase {
+class reportView : public KDialog {
     Q_OBJECT
 
 public:
-    reportView(const QString &reportLocation);
+    explicit reportView(const QString &reportLocation);
     ~reportView();
 
     void render();
 
 private:
-    WeatherService_stub *m_weatherService;
+    OrgKdeKweatherServiceInterface *m_weatherService;
     KHTMLPart *m_reportView;
     QString m_locationCode;
 };
